@@ -67,6 +67,12 @@ sub _set_error {
     }
 }
 
+sub _clear_error_and_status {
+    my $sftp = shift;
+    $sftp->{_error} = 0;
+    $sftp->{_status} = 0;
+}
+
 sub _copy_error {
     $_[0]->{_error} = $_[1]->{_error};
 }
@@ -158,7 +164,7 @@ sub find {
                     next unless (defined $rp and not $rpdone{$rp}++);
 		}
 	    }
-		
+
 	    if ($follow) {
                 my $a = $self->stat($fn);
                 if (defined $a) {
@@ -168,7 +174,7 @@ sub find {
                 }
 		next;
 	    }
-		
+
 	    if (!$wanted or $wanted->($self, $entry)) {
 		if ($wantarray) {
                     push @res, ( $names_only
@@ -192,11 +198,12 @@ sub find {
 	no warnings 'uninitialized';
 	$try = shift @queue;
 	my $fn = $try->{filename};
-	next if $done{$fn}++;
 
 	my $a = $try->{a} ||= $self->lstat($fn)
 	    or next;
 
+	next if (S_ISDIR($a->perm) and $done{$fn}++);
+
 	$task->($try);
 
 	if (S_ISDIR($a->perm)) {
